summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--Makefile.am4
-rw-r--r--distro.scm2
-rw-r--r--distro/packages/base.scm (renamed from distro/base.scm)5
-rw-r--r--distro/packages/ld-wrapper.scm (renamed from distro/ld-wrapper.scm)4
-rw-r--r--guix/build-system/gnu.scm4
-rw-r--r--tests/packages.scm2
6 files changed, 11 insertions, 10 deletions
diff --git a/Makefile.am b/Makefile.am
index 3de64a4edd..88f3d87796 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -35,8 +35,8 @@ MODULES =					\
   guix/packages.scm				\
   guix.scm					\
   distro.scm					\
-  distro/base.scm				\
-  distro/ld-wrapper.scm
+  distro/packages/base.scm			\
+  distro/packages/ld-wrapper.scm
 
 GOBJECTS = $(MODULES:%.scm=%.go)
 
diff --git a/distro.scm b/distro.scm
index b21b0e6184..79e09a3cc6 100644
--- a/distro.scm
+++ b/distro.scm
@@ -48,7 +48,7 @@
 (define %distro-module-directory
   ;; Absolute path of the (distro ...) module root.
   (string-append (dirname (search-path %load-path "distro.scm"))
-                 "/distro"))
+                 "/distro/packages"))
 
 (define (package-files)
   "Return the list of files that implement distro modules."
diff --git a/distro/base.scm b/distro/packages/base.scm
index bf49d02f20..67b8b1c602 100644
--- a/distro/base.scm
+++ b/distro/packages/base.scm
@@ -16,7 +16,7 @@
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with Guix.  If not, see <http://www.gnu.org/licenses/>.
 
-(define-module (distro base)
+(define-module (distro packages base)
   #:use-module (distro)
   #:use-module (guix packages)
   #:use-module (guix ftp)
@@ -1676,7 +1676,8 @@ exec ~a/bin/~a-gcc -B~a/lib -Wl,-dynamic-linker -Wl,~a/lib/~a \"$@\"~%"
     (build-system trivial-build-system)
     (inputs `(("binutils" ,binutils-final)
               ("guile"   ,(nixpkgs-derivation* "guile"))
-              ("wrapper" ,(search-path %load-path "distro/ld-wrapper.scm"))))
+              ("wrapper" ,(search-path %load-path
+                                       "distro/packages/ld-wrapper.scm"))))
     (arguments
      `(#:modules ((guix build utils))
        #:builder (begin
diff --git a/distro/ld-wrapper.scm b/distro/packages/ld-wrapper.scm
index 9d3e8008b3..9b8a09f067 100644
--- a/distro/ld-wrapper.scm
+++ b/distro/packages/ld-wrapper.scm
@@ -7,7 +7,7 @@
 # Use `load-compiled' because `load' (and `-l') doesn't otherwise load our
 # .go file (see <http://bugs.gnu.org/12519>).
 
-main="(@ (distro ld-wrapper) ld-wrapper)"
+main="(@ (distro packages ld-wrapper) ld-wrapper)"
 exec @GUILE@ -c "(load-compiled \"$0.go\") (apply $main (cdr (command-line)))" "$@"
 !#
 ;;; Guix --- Nix package management from Guile.         -*- coding: utf-8 -*-
@@ -28,7 +28,7 @@ exec @GUILE@ -c "(load-compiled \"$0.go\") (apply $main (cdr (command-line)))" "
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with Guix.  If not, see <http://www.gnu.org/licenses/>.
 
-(define-module (distro ld-wrapper)
+(define-module (distro packages ld-wrapper)
   #:use-module (srfi srfi-1)
   #:export (ld-wrapper))
 
diff --git a/tests/packages.scm b/tests/packages.scm
index 48a4a38fea..20f586e449 100644
--- a/tests/packages.scm
+++ b/tests/packages.scm
@@ -25,7 +25,7 @@
   #:use-module (guix build-system trivial)
   #:use-module (guix build-system gnu)
   #:use-module (distro)
-  #:use-module (distro base)
+  #:use-module (distro packages base)
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-64)
   #:use-module (ice-9 match))
diff --git a/guix/build-system/gnu.scm b/guix/build-system/gnu.scm
index 20f5bbacfc..b4a498bee7 100644
--- a/guix/build-system/gnu.scm
+++ b/guix/build-system/gnu.scm
@@ -87,8 +87,8 @@ System: GCC, GNU Make, Bash, Coreutils, etc."
            (z
             (error "invalid standard input" z)))
 
-          ;; Resolve (distro base) lazily to hide circular dependency.
-          (let* ((distro (resolve-module '(distro base)))
+          ;; Resolve (distro packages base) lazily to hide circular dependency.
+          (let* ((distro (resolve-module '(distro packages base)))
                  (inputs (module-ref distro '%final-inputs)))
             (append inputs
                     (append-map (match-lambda